@@ -73,7 +73,7 @@ pub struct DrawingCtx<'a> {
     drawsub_stack: Vec<RsvgNode>,
 
     defs: RefCell<&'a mut Defs>,
-    acquired_nodes: RefCell<Vec<RsvgNode>>,
+    acquired_nodes: Rc<RefCell<Vec<RsvgNode>>>,
 
     is_testing: bool,
 }
@@ -125,7 +125,7 @@ impl<'a> DrawingCtx<'a> {
             bbox_stack: Vec::new(),
             drawsub_stack: Vec::new(),
             defs: RefCell::new(defs),
-            acquired_nodes: RefCell::new(Vec::new()),
+            acquired_nodes: Rc::new(RefCell::new(Vec::new())),
             is_testing,
         }
     }
@@ -213,7 +213,7 @@ impl<'a> DrawingCtx<'a> {
         if let Some(node) = self.defs.borrow_mut().lookup(url) {
             if !self.acquired_nodes_contains(node) {
                 self.acquired_nodes.borrow_mut().push(node.clone());
-                return Some(AcquiredNode(&self.acquired_nodes as *const _, node.clone()));
+                return Some(AcquiredNode(self.acquired_nodes.clone(), node.clone()));
             }
         }
 
@@ -286,31 +286,24 @@ impl<'a> DrawingCtx<'a> {
 
             let affine = original_cr.get_matrix();
 
-            let (clip_node, clip_units) = {
-                let clip_node = self
-                    .get_acquired_node_of_type(clip_uri, NodeType::ClipPath)
-                    .and_then(|acquired| Some(acquired.get()));
+            let (acquired_clip, clip_units) = {
+                if let Some(acquired) = self.get_acquired_node_of_type(clip_uri, NodeType::ClipPath)
+                {
+                    let ClipPathUnits(units) = acquired
+                        .get()
+                        .with_impl(|clip_path: &NodeClipPath| clip_path.get_units());
 
-                let mut clip_units = Default::default();
-
-                if let Some(ref clip_node) = clip_node {
-                    clip_node.with_impl(|clip_path: &NodeClipPath| {
-                        let ClipPathUnits(u) = clip_path.get_units();
-                        clip_units = Some(u);
-                    });
+                    (Some(acquired), Some(units))
+                } else {
+                    (None, None)
                 }
-
-                (clip_node, clip_units)
             };
 
             if clip_units == Some(CoordUnits::UserSpaceOnUse) {
-                let res = if let Some(ref clip_node) = clip_node {
-                    clip_node.with_impl(|clip_path: &NodeClipPath| {
-                        clip_path.to_cairo_context(clip_node, &affine, self)
-                    })
-                } else {
-                    Ok(())
-                };
+                let clip_node = acquired_clip.as_ref().unwrap().get();
+                let res = clip_node.with_impl(|clip_path: &NodeClipPath| {
+                    clip_path.to_cairo_context(clip_node, &affine, self)
+                });
 
                 if let Err(e) = res {
                     original_cr.restore();
@@ -400,13 +393,10 @@ impl<'a> DrawingCtx<'a> {
                 original_cr.set_source_surface(&filter_result_surface, xofs, yofs);
 
                 if clip_units == Some(CoordUnits::ObjectBoundingBox) {
-                    let res = if let Some(ref clip_node) = clip_node {
-                        clip_node.with_impl(|clip_path: &NodeClipPath| {
-                            clip_path.to_cairo_context(clip_node, &affine, self)
-                        })
-                    } else {
-                        Ok(())
-                    };
+                    let clip_node = acquired_clip.as_ref().unwrap().get();
+                    let res = clip_node.with_impl(|clip_path: &NodeClipPath| {
+                        clip_path.to_cairo_context(clip_node, &affine, self)
+                    });
 
                     if let Err(e) = res {
                         original_cr.restore();
@@ -1026,21 +1016,19 @@ pub extern "C" fn rsvg_drawing_ctx_get_ink_rect(
     res.to_glib()
 }
 
-pub struct AcquiredNode(*const RefCell<Vec<RsvgNode>>, RsvgNode);
+pub struct AcquiredNode(Rc<RefCell<Vec<RsvgNode>>>, RsvgNode);
 
 impl Drop for AcquiredNode {
     fn drop(&mut self) {
-        unsafe {
-            let mut v = (*self.0).borrow_mut();
-            assert!(Rc::ptr_eq(v.last().unwrap(), &self.1));
-            v.pop();
-        }
+        let mut v = self.0.borrow_mut();
+        assert!(Rc::ptr_eq(v.last().unwrap(), &self.1));
+        v.pop();
     }
 }
 
 impl AcquiredNode {
-    pub fn get(&self) -> RsvgNode {
-        self.1.clone()
+    pub fn get(&self) -> &RsvgNode {
+        &self.1
     }
 }
 
