@@ -1,6 +1,7 @@
 use std::error;
 use std::fmt;
 
+use cairo;
 use cssparser::BasicParseError;
 
 use attributes::Attribute;
@@ -82,6 +83,21 @@ impl<'a> From<BasicParseError<'a>> for AttributeError {
     }
 }
 
+#[derive(Clone)]
+pub enum RenderingError {
+    Cairo(cairo::Status),
+    CircularReference,
+    InstancingLimit,
+}
+
+impl From<cairo::Status> for RenderingError {
+    fn from(e: cairo::Status) -> RenderingError {
+        assert!(e != cairo::Status::Success);
+
+        RenderingError::Cairo(e)
+    }
+}
+
 #[cfg(test)]
 pub fn is_parse_error<T>(r: &Result<T, AttributeError>) -> bool {
     match *r {
