@@ -243,8 +243,11 @@ fn font_size_from_values(values: &ComputedValues, draw_ctx: &DrawingCtx) -> f64
 
         LengthUnit::Inch => font_size_from_inch(v.length, v.dir, draw_ctx),
 
-        LengthUnit::Percent | LengthUnit::FontEm | LengthUnit::FontEx => {
-            unreachable!("ComputedValues can't have a relative font size")
+        LengthUnit::Percent => unreachable!("ComputedValues can't have a relative font size"),
+
+        LengthUnit::FontEm | LengthUnit::FontEx => {
+            // This is the same default as used in rsvg_node_svg_get_size()
+            v.hand_normalize(0.0, 0.0, 12.0)
         }
     }
 }
