@@ -286,10 +286,11 @@ impl NodeTrait for NodeUse {
             return Ok(());
         }
 
-        let acquired = draw_ctx.get_acquired_node(link.as_ref().unwrap());
-
-        let child = if let Some(acquired) = acquired {
-            acquired.get()
+        let child = if let Some(acquired) = draw_ctx.get_acquired_node(link.as_ref().unwrap()) {
+            // Here we clone the acquired child, so that we can drop the AcquiredNode as
+            // early as possible.  This is so that the child's drawing method will be able
+            // to re-acquire the child for other purposes.
+            acquired.get().clone()
         } else {
             return Ok(());
         };
